[![Documentation Status](https://readthedocs.org/projects/aiidalab-widgets-base/badge/?version=latest)](https://aiidalab-widgets-base.readthedocs.io/en/latest/?badge=latest)

# Base widgets for AiiDAlab

## Installation

Install the `aiidalab_widgets_base` python package via:
```
pip install aiidalab-widgets-base 
```

Install the corresponding `aiidalab-widgets-base` AiiDAlab application
via the app manager as usual.

### Optional dependencies

* The `SmilesWidget` widget requires the [OpenBabel](http://openbabel.org/) library.

## Documentation
The documentation can be found on the [following web page](https://aiidalab-widgets-base.readthedocs.io).

## Usage

Using the widgets usually just involves importing and displaying them.
For demos, have a look at the jupyter notebooks (`.ipynb` extension) in
this folder.

## License

MIT

## Contact

aiidalab@materialscloud.org

## Acknowledgements

This work is supported by the [MARVEL National Centre for Competency in Research](<http://nccr-marvel.ch>)
funded by the [Swiss National Science Foundation](<http://www.snf.ch/en>), as well as by the [MaX
European Centre of Excellence](<http://www.max-centre.eu/>) funded by the Horizon 2020 EINFRA-5 program,
Grant No. 676598.

![MARVEL](miscellaneous/logos/MARVEL.png)
![MaX](miscellaneous/logos/MaX.png)
